@@ -158,10 +158,23 @@ class MinBarStream(object):
         bar.turnover = reader.read_double()
         bar.open_interest = reader.read_double()
         bar.IsCompleted = True
+        bar_time_delta = datetime.timedelta(hours=bar.end_time.hour, minutes=bar.end_time.minute, seconds=bar.end_time.second, microseconds=bar.end_time.microsecond)
+
         standard_time_delta = datetime.timedelta(hours=15, minutes=0, seconds=0)
         begin_time_delta = datetime.timedelta(hours=14, minutes=59, seconds=1)
-        end_time_delta = datetime.timedelta(hours=15, minutes=30, seconds=0)
-        bar_time_delta = datetime.timedelta(hours=bar.end_time.hour, minutes=bar.end_time.minute, seconds=bar.end_time.second, microseconds=bar.end_time.microsecond)
+        end_time_delta = datetime.timedelta(hours=15, minutes=0, seconds=59)
+        if begin_time_delta < bar_time_delta < end_time_delta and bar_time_delta != standard_time_delta:
+            bar.end_time = datetime.datetime(bar.end_time.year, bar.end_time.month, bar.end_time.day) + standard_time_delta
+
+        standard_time_delta = datetime.timedelta(hours=15, minutes=15, seconds=0)
+        begin_time_delta = datetime.timedelta(hours=15, minutes=14, seconds=1)
+        end_time_delta = datetime.timedelta(hours=15, minutes=15, seconds=59)
+        if begin_time_delta < bar_time_delta < end_time_delta and bar_time_delta != standard_time_delta:
+            bar.end_time = datetime.datetime(bar.end_time.year, bar.end_time.month, bar.end_time.day) + standard_time_delta
+
+        standard_time_delta = datetime.timedelta(hours=15, minutes=30, seconds=0)
+        begin_time_delta = datetime.timedelta(hours=15, minutes=29, seconds=1)
+        end_time_delta = datetime.timedelta(hours=15, minutes=30, seconds=59)
         if begin_time_delta < bar_time_delta < end_time_delta and bar_time_delta != standard_time_delta:
             bar.end_time = datetime.datetime(bar.end_time.year, bar.end_time.month, bar.end_time.day) + standard_time_delta
 
